==> qbs-src-1.7.2.zip: qbs-src-1.7.2/src/lib/corelib/buildgraph/forward_decls.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_BG_FORWARD_DECLS_H
#define QBS_BG_FORWARD_DECLS_H

#include <QSharedPointer>

namespace qbs {
namespace Internal {

class Artifact;
class ArtifactSet;
class ProjectBuildData;
class ProductBuildData;
class Node;
class NodeSet;

class Transformer;
typedef QSharedPointer<Transformer> TransformerPtr;
typedef QSharedPointer<const Transformer> TransformerConstPtr;

class RulesEvaluationContext;
typedef QSharedPointer<RulesEvaluationContext> RulesEvaluationContextPtr;

class AbstractCommand;
typedef QSharedPointer<AbstractCommand> AbstractCommandPtr;

class ProcessCommand;
typedef QSharedPointer<ProcessCommand> ProcessCommandPtr;

class JavaScriptCommand;
typedef QSharedPointer<JavaScriptCommand> JavaScriptCommandPtr;

} // namespace Internal
} // namespace qbs

#endif // QBS_BG_FORWARD_DECLS_H

==> qbs-src-1.8.1.zip: qbs-src-1.8.1/src/lib/corelib/buildgraph/forward_decls.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_BG_FORWARD_DECLS_H
#define QBS_BG_FORWARD_DECLS_H

#include <QtCore/qsharedpointer.h>

namespace qbs {
namespace Internal {

class Artifact;
class BuildGraphNode;
class ProjectBuildData;
class ProductBuildData;
class Node;

class Transformer;
typedef QSharedPointer<Transformer> TransformerPtr;
typedef QSharedPointer<const Transformer> TransformerConstPtr;

class RulesEvaluationContext;
typedef QSharedPointer<RulesEvaluationContext> RulesEvaluationContextPtr;

class AbstractCommand;
typedef QSharedPointer<AbstractCommand> AbstractCommandPtr;

class ProcessCommand;
typedef QSharedPointer<ProcessCommand> ProcessCommandPtr;

class JavaScriptCommand;
typedef QSharedPointer<JavaScriptCommand> JavaScriptCommandPtr;

template<typename T> class Set;
using ArtifactSet = Set<Artifact *>;
using NodeSet = Set<BuildGraphNode *>;

} // namespace Internal
} // namespace qbs

#endif // QBS_BG_FORWARD_DECLS_H
